summaryrefslogtreecommitdiff
path: root/lisp/dired-x.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/dired-x.el')
-rw-r--r--lisp/dired-x.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/dired-x.el b/lisp/dired-x.el
index 1012deccd3c..f176cf7dbe0 100644
--- a/lisp/dired-x.el
+++ b/lisp/dired-x.el
@@ -800,8 +800,8 @@ See also `dired-enable-local-variables'."
(hack-local-variables))
;; Delete this stuff: `eobp' is used to find last subdir by dired.el.
(delete-region opoint (point-max)))
- ;; Make sure that the modeline shows the proper information.
- (dired-sort-set-modeline))))
+ ;; Make sure that the mode line shows the proper information.
+ (dired-sort-set-mode-line))))
(make-obsolete 'dired-hack-local-variables
'hack-dir-local-variables-non-file-buffer "24.1")